@@ -193,7 +193,7 @@ predict.blockForest.forest <- function(object, data, predict.all = FALSE,
   ## Num threads
   ## Default 0 -> detect from system in C++.
   if (is.null(num.threads)) {
-    num.threads = 0
+    num.threads <- as.integer(Sys.getenv("R_BLOCKFOREST_NUM_THREADS", getOption("blockforest.num.threads", getOption("Ncpus", 0L))))
   } else if (!is.numeric(num.threads) || num.threads < 0) {
     stop("Error: Invalid value for num.threads")
   }
